@@ -2,12 +2,11 @@
 
 use strict;
 use warnings;
-
 use Tie::DiskUsage;
 
 my $path = '/var';
 my $log  = "$path/log";
 
 tie my %usage, 'Tie::DiskUsage', $path, '-h';
-print "$log: $usage{$log}\n";
+print "$usage{$log}\t$log\n";
 untie %usage;
